# Mathematical model of chemotherapy and SMAC mimetics in Colorectal Cancer
---------------------------------------------------------------------------

Software supplement to "Simulating and predicting cellular and *in vivo*
responses of colon cancer to combined treatment with chemotherapy and IAP
antagonist Birinapant/TL32711" authored by Nyree Crawford, Manuela Salvucci,
Christian T Hellwig, Frank A Lincoln, Ruth E Mooney, Carla L O'Connor,
Jochen HM Prehn, Daniel B Longley, Markus Rehm.


## Data and software

We provide the source code and the required experimental data to reproduce
the computational analyses and corresponding figures presented in the paper:

* Figure 3, panels C-D;
* Figure 4, panels C-E;
* Figure 5, panels D-E;
* Figure 6, panels A-B and E-G;
* Supplementary Figure 1, panels A-D.

### Requirements

The following software and toolboxes are required:

* MATLAB (release 2014b) with:
	*  Parallel Computing Toolbox;
	*  Statistics Toolbox;
	*  Optimization Toolbox.

### Directory content and layout

The supplement software has the following file structure:

* **data:** primary experimental results used to parameterize the extended
  APOPTO-CELL model. Detailed desciptions of the data files are found in
  the corresponding code books in the same directory.

* **+cohort_utilities:** utility package to prepare, run and analyse
  simulation results generated by the APOPTO-CELL model.

* **+matlab_utilities:** utility package with helper functions for data
  handling, processing and plotting. This package also includes third-party
  software from [MATLAB file exchange](https://uk.mathworks.com/matlabcentral/fileexchange/).
  See source.md and licence.txt files for details.

* **SimulateEnsembleExtendedApoptoCellModel:** run an ensemble of simulations for
  the extended APOPTO-CELL model which includes upstream signalling
  activation prior to mitochondrial engagement for HCT116 and LoVo cell
  lines treated with 5FU + OXALI, TL32711 and 5FU + OXALI + TL32711 for the
  *in vitro* and *in vivo* settings. See ExtendedApoptoCell.m and
  +cohort_utilities/ for details.

* **SimulateEnsembleApoptoCellModel:** run an ensemble of simulations for
  the APOPTO-CELL model (Rehm et al., EMBO, 2006) for HCT116 and LoVo cell
  lines treated with 5FU + OXALI, TL32711 and 5FU + OXALI + TL32711 for the
  *in vitro* and *in vivo* settings. See +cohort_utilities/ for details.

* **FitInVivoTumourVolume:** run fitting routines to find the drug efficacy
  parameters for each treatment (5FU + OXALI, TL32711 and 5FU + OXALI + TL32711)
  for HCT116 and LoVo cell line xenografts. Tumour volume growth was modelled
  as detailed in TumourVolume.m.

* **MakePaperFigures:** generate figures corresponding to the computational
  analyses:

    * MakeFigure3PanelsC_D.m
    * MakeFigure4PanelsC_D_E.m
    * MakeFigure5PanelsD_E.m
    * MakeFigure6PanelsA_B.m
    * MakeFigure6PanelsE_F_G.m
    * MakeSupplementaryFigure1.m
    * MakeAuxiliaryFigures1_2.m

More information can be found within each file.

### Usage

Run the following functions in order:

1. Run `SimulateEnsembleExtendedApoptoCellModel` to generate
   'extended_apoptocell_ensemble_simulations.mat';
2. Run `SimulateEnsembleApoptoCellModel` to generate
   'apoptocell_ensemble_simulations.mat';
3. Run `FitInVivoTumourVolume` to generate
   'in_vivo_tumour_volume_fittings.mat';
4. Run `MakePaperFigures` to generate figures from the paper in a folder
   named 'figures'.


## Citation

When using these datasets and code, please cite https://doi.org/10.5281/zenodo.1067500
and the corresponding paper.


## More information

For further information regarding the supplemental software, please contact:

* Prof. Markus Rehm (markus.morrison@izi.uni-stuttgart.de);
* Prof. Daniel B Longley (d.longley@qub.ac.uk);
* Prof. Jochen H M Prehn (JPrehn@rcsi.ie);
* Manuela Salvucci (manuelasalvucci@rcsi.ie).

----------------------
